---
layout: graph
title: Repository Languages
---

<svg id="languages"></svg>
<script src="{{ site.baseurl }}/assets/js/extractors/languages.js"></script>

<script>
$(document).ready(function(){
  draw_pie_languages('#languages');
})
</script>
